# Smart Drawer

import board
import time
import digitalio
import neopixel
from adafruit_pixel_framebuf import PixelFramebuffer
from adafruit_pixel_framebuf import VERTICAL
from audiopwmio import PWMAudioOut as AudioOut
from audiocore import WaveFile
import adafruit_lis3dh
import busio

pixel_pin = board.A6
pixel_width = 32
pixel_height = 8

pixels = neopixel.NeoPixel(board.NEOPIXEL, 10, brightness = 0.3, auto_write = True)

pixel = neopixel.NeoPixel(
    pixel_pin,
    pixel_width * pixel_height,
    brightness=0.1,
    auto_write=False,
)

pixel_framebuf = PixelFramebuffer(
    pixel,
    pixel_height,
    pixel_width,
    alternating=True,
    #orientation=VERTICAL,
    #reverse_y=True,
    reverse_x=True,
    rotation=1
)

extswitch = digitalio.DigitalInOut(board.A2)
extswitch.switch_to_input(pull=digitalio.Pull.UP)

relay = digitalio.DigitalInOut(board.A1)
relay.direction = digitalio.Direction.OUTPUT
relay.value = False

# initializing accrometer
i2c = busio.I2C(board.ACCELEROMETER_SCL, board.ACCELEROMETER_SDA)
int1 = digitalio.DigitalInOut(board.ACCELEROMETER_INTERRUPT)
accelerometer = adafruit_lis3dh.LIS3DH_I2C(i2c, address=0x19)
accelerometer.range = adafruit_lis3dh.RANGE_8_G

# configure speaker
speaker = digitalio.DigitalInOut(board.SPEAKER_ENABLE)
speaker.direction = digitalio.Direction.OUTPUT
speaker.value = True
audio = AudioOut(board.SPEAKER)

def play_sound(filename):
    with open(filename, "rb") as wave_file:
        wave = WaveFile(wave_file)
        audio.play(wave)
        while audio.playing:
            pass

def welcome(filename):
    with open(filename, "rb") as wave_file:
        wave = WaveFile(wave_file)
        audio.play(wave)
        while audio.playing:
            text_prompt()

def relay_open():
    relay.value = True
    time.sleep(0.01)
    relay.value = False

def text_prompt():
    text = 'Thank you!'
    pixel_framebuf.fill(0x000000)
    pixel_framebuf.text(text, pixel_width, 0, 0x00FFFF)
    pixel_framebuf.display()
    for i in range((pixel_width+len(text)*6)/3):
        #pixel_framebuf.scroll(0, 1)
        pixel_framebuf.fill(0x000000)
        pixel_framebuf.text(text, pixel_width-i*3, 0, 0x00FFFF)
        pixel_framebuf.display()
        #time.sleep(0.001)


# False = sound off
# True = sound on
sound_on = False


while True:
    x, y, z = accelerometer.acceleration
    #print((x, y, z))
    if z < -8.5:
        pixel_framebuf.fill(0x000000)
        pixel_framebuf.text('SET:', 0, 0, 0xFF0000)
        if sound_on:
            pixel_framebuf.text('ON', 20, 0, 0x00FF00)
        else:
            pixel_framebuf.text('OFF', 20, 0, 0xFF0000)
        pixel_framebuf.display()
        if not extswitch.value:
            sound_on = not sound_on
            if sound_on:
                pixel_framebuf.fill(0x000000)
                pixel_framebuf.text('SET:', 0, 0, 0xFF0000)
                pixel_framebuf.text('ON', 20, 0, 0x00FF00)
                pixel_framebuf.display()
                play_sound('sound_on.wav')
                while not extswitch.value:
                    pass
            else:
                pixel_framebuf.fill(0x000000)
                pixel_framebuf.text('SET:', 0, 0, 0xFF0000)
                pixel_framebuf.text('OFF', 20, 0, 0xFF0000)
                pixel_framebuf.display()
                play_sound('sound_off.wav')
                while not extswitch.value:
                    pass

    else:
        pixel_framebuf.fill(0x000000)
        pixel_framebuf.display()
        if not extswitch.value:
            relay_open()
            if sound_on:
                welcome("HelloWelcome.wav")
            else:
                text_prompt()
            while not extswitch.value:
                pass
        else:
            relay.value = False
            pixels.fill((0, 0, 0))


